# $Id: /mirror/coderepos/lang/perl/Data-Localize/trunk/t/lib/Test/Data/Localize/Namespace/ja.pm 100685 2009-02-15T02:33:48.375991Z daisuke  $

package Test::Data::Localize::Namespace::ja;
use utf8;

our %Lexicon = (
    'Hello, stranger!' => "[_1]さん、こんにちは!"
);

1;